@@ -9,7 +9,7 @@ from pathlib import Path
 
 from openpyxl import load_workbook
 
-from simple_export.excel import write_excel_for_template
+from excel import write_excel_for_template
 
 def test1():
     wb_tmp = load_workbook(Path(__file__).parent / 'template/excel1.xlsx')
@@ -763,7 +763,7 @@ def test3():
          'three_benchmark': '建有清洁生产领导机构，成员单位与主管人员分工明确；有清洁生产管理制度和奖励管理办法；定期开展清洁生产审核活动，清洁生产方案实施率≥50%；有开展清洁生产工作记录',
          'proce_id': 13, 'index_value': None, 'level': None, 'score': None, 'parent_name': '环境管理要求',
          'parent_weighted_value': '0.1'}]}, 'data': {}}
-    wb_tmp = load_workbook(Path(__file__).parent / 'template/excel3.xlsx')
+    wb_tmp = load_workbook(Path(__file__).parent / 'template/excel4.xlsx')
     write_excel_for_template(value=d, wb_tmp=wb_tmp, convert_pic=True)
     wb_tmp.save("./val3.xlsx")
 
