@@ -165,8 +165,6 @@ class work_sheet_tool():
                     if pos[i][j] == 0:
                         self.replace_pos(i, j, pos)
                     if j not in pos_mapping[i]:
-                        if i == 5 and j == 2:
-                            print(1)
                         pos_mapping[i].setdefault(j, []).append(
                             pos_mapping[i - 1][j][-1] + 1 if i - 1 > 0 else i
                         )
@@ -210,8 +208,8 @@ class work_sheet_tool():
                 w += maxn
             i += 1
         target.insert_rows(len(pos))
-        if len(source.column_dimensions) > 0:
-            target.column_dimensions = copy.deepcopy(source.column_dimensions)
+        for index in source.column_dimensions:
+            target.column_dimensions[index].width = source.column_dimensions[index].width
         for index in source.row_dimensions:
             for pm in max(list(pos_mapping[index - 1].values())):
                 height = source.row_dimensions[index].height
@@ -225,13 +223,10 @@ class work_sheet_tool():
                     target_cell: Cell = target.cell(i + 1, j + 1)
                     self.copy_cell(source_cell, target_cell)
         for i, cell in enumerate(source.merged_cells):
-            print(cell)
             cell_min_num = pos_mapping[cell.min_row - 1][cell.min_col - 1][0] + 1
             cell_max_num = pos_mapping[cell.max_row - 1][cell.max_col - 1][0] + 1
             target.merge_cells(start_row=cell_min_num, start_column=cell.min_col,
                             end_column=cell.max_col, end_row=cell_max_num)
-            if i > 3:
-                print(1)
         self.exec_task(target, pos_mapping, pos)
         self.write_table(source, target, pos_mapping)
         self.write_attr(source, target, pos_mapping)
